@@ -24,7 +24,7 @@ pub struct Cursor {
     pub y: u16,
 }
 
-pub(crate) struct FilesystemScan {
+pub struct FilesystemScan {
     pub active_traversal: BackgroundTraversal,
     /// The selected item prior to starting the traversal, if available, based on its name or index into [`AppState::entries`].
     pub previous_selection: Option<(PathBuf, usize)>,
@@ -44,6 +44,8 @@ pub struct AppState {
     pub walk_options: WalkOptions,
     /// The paths used in the initial traversal, at least 1.
     pub root_paths: Vec<PathBuf>,
+    /// If true, listed entries will be validated for presence when switching directories.
+    pub allow_entry_check: bool,
 }
 
 impl AppState {
@@ -61,6 +63,7 @@ impl AppState {
             stats: TraversalStats::default(),
             walk_options,
             root_paths: input,
+            allow_entry_check: true,
         }
     }
 }
