@@ -7,6 +7,7 @@ use chrono::DateTime;
 use dua::traverse::TreeIndex;
 use itertools::Itertools;
 use std::borrow::{Borrow, Cow};
+use std::collections::HashSet;
 use std::time::SystemTime;
 use tui::{
     buffer::Buffer,
@@ -33,6 +34,7 @@ pub struct EntriesProps<'a> {
     pub border_style: Style,
     pub is_focussed: bool,
     pub sort_mode: SortMode,
+    pub show_columns: &'a HashSet<Column>,
 }
 
 #[derive(Default)]
@@ -56,16 +58,23 @@ impl Entries {
             border_style,
             is_focussed,
             sort_mode,
+            show_columns,
         } = props.borrow();
         let list = &mut self.list;
 
         let total: u128 = entries.iter().map(|b| b.size).sum();
-        let (item_count, item_size): (u64, u128) = entries
+        let (recursive_item_count, item_size): (u64, u128) = entries
             .iter()
             .map(|f| (f.entry_count.unwrap_or(1), f.size))
             .reduce(|a, b| (a.0 + b.0, a.1 + b.1))
             .unwrap_or_default();
-        let title = title(current_path, item_count, *display, item_size);
+        let title = title(
+            current_path,
+            entries.len(),
+            recursive_item_count,
+            *display,
+            item_size,
+        );
         let title_block = title_block(&title, *border_style);
         let inner_area = title_block.inner(area);
         let entry_in_view = entry_in_view(*selected, entries);
@@ -87,7 +96,7 @@ impl Entries {
             let percentage_style = percentage_style(fraction, text_style);
 
             let mut columns = Vec::new();
-            if show_mtime_column(sort_mode) {
+            if show_mtime_column(sort_mode, show_columns) {
                 columns.push(mtime_column(
                     bundle.mtime,
                     column_style(Column::MTime, *sort_mode, text_style),
@@ -99,7 +108,7 @@ impl Entries {
                 column_style(Column::Bytes, *sort_mode, text_style),
             ));
             columns.push(percentage_column(*display, fraction, percentage_style));
-            if show_count_column(sort_mode) {
+            if show_count_column(sort_mode, show_columns) {
                 columns.push(count_column(
                     bundle.entry_count,
                     column_style(Column::Count, *sort_mode, text_style),
@@ -152,15 +161,17 @@ fn title_block(title: &str, border_style: Style) -> Block<'_> {
         .borders(Borders::ALL)
 }
 
-fn title(current_path: &str, item_count: u64, display: DisplayOptions, size: u128) -> String {
+fn title(
+    current_path: &str,
+    item_count: usize,
+    recursive_item_count: u64,
+    display: DisplayOptions,
+    size: u128,
+) -> String {
     format!(
-        " {} ({} item{}, {}) ",
+        " {} ({item_count} visible, {} total, {}) ",
         current_path,
-        COUNT.format(item_count as f64),
-        match item_count {
-            1 => "",
-            _ => "s",
-        },
+        COUNT.format(recursive_item_count as f64),
         display.byte_format.display(size)
     )
 }
@@ -323,8 +334,8 @@ fn bytes_column(display: DisplayOptions, entry_size: u128, style: Style) -> Span
     )
 }
 
-#[derive(PartialEq)]
-enum Column {
+#[derive(PartialEq, Eq, Hash)]
+pub enum Column {
     Bytes,
     MTime,
     Count,
@@ -344,18 +355,18 @@ fn column_style(column: Column, sort_mode: SortMode, style: Style) -> Style {
     }
 }
 
-fn show_mtime_column(sort_mode: &SortMode) -> bool {
+fn show_mtime_column(sort_mode: &SortMode, show_columns: &HashSet<Column>) -> bool {
     matches!(
         sort_mode,
         SortMode::MTimeAscending | SortMode::MTimeDescending
-    )
+    ) || show_columns.contains(&Column::MTime)
 }
 
-fn show_count_column(sort_mode: &SortMode) -> bool {
+fn show_count_column(sort_mode: &SortMode, show_columns: &HashSet<Column>) -> bool {
     matches!(
         sort_mode,
         SortMode::CountAscending | SortMode::CountDescending
-    )
+    ) || show_columns.contains(&Column::Count)
 }
 
 /// Note that this implementation isn't correct as `width` is the amount of blocks to display,
